==> haskell-options-1.2.1.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-options-z-options-internal
version:              1.2.1.2
package-name:         options
lib-name:             options-internal
id:                   options-1.2.1.2-18dyjDpSGBv6m1ZRYauZpc-options-internal
key:                  options-1.2.1.2-18dyjDpSGBv6m1ZRYauZpc-options-internal
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  2d47c9dba7d1926b56d6531085c53fd3
exposed-modules:
    Options.Help Options.Tokenize Options.Types Options.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-18dyjDpSGBv6m1ZRYauZpc-options-internal
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.1-EWNCSzWUnVI56Lvw8xK8It

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 options
version:              1.2.1.2
visibility:           public
id:                   options-1.2.1.2-HBhMTKilOR7Iil2vAUvuXv
key:                  options-1.2.1.2-HBhMTKilOR7Iil2vAUvuXv
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  0130d3fc77be559332ea2ff001e44e2a
exposed:              True
exposed-modules:      Options
import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-HBhMTKilOR7Iil2vAUvuXv
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.1-EWNCSzWUnVI56Lvw8xK8It
    options-1.2.1.2-18dyjDpSGBv6m1ZRYauZpc-options-internal

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-options-1.2.1.2-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-options-z-options-internal
version:              1.2.1.2
package-name:         options
lib-name:             options-internal
id:                   options-1.2.1.2-7mKTVYZoCqJHgb7W6ibZ1L-options-internal
key:                  options-1.2.1.2-7mKTVYZoCqJHgb7W6ibZ1L-options-internal
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  ed054fa2bf6b1de585425553744a58a8
exposed-modules:
    Options.Help Options.Tokenize Options.Types Options.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-7mKTVYZoCqJHgb7W6ibZ1L-options-internal
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.1-EWNCSzWUnVI56Lvw8xK8It

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 options
version:              1.2.1.2
visibility:           public
id:                   options-1.2.1.2-HHY63MDdMcK2tG3o0Dtg3z
key:                  options-1.2.1.2-HHY63MDdMcK2tG3o0Dtg3z
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  5c550c76fb404d2da613f53cf9302c25
exposed:              True
exposed-modules:      Options
import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-HHY63MDdMcK2tG3o0Dtg3z
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.1-EWNCSzWUnVI56Lvw8xK8It
    options-1.2.1.2-7mKTVYZoCqJHgb7W6ibZ1L-options-internal

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
